#
# spec file for package codec2
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname lib%{name}-1_2
Name:           codec2
Version:        1.2.0
Release:        1.4
Summary:        Low bit rate speech codec
# octave/plot_fsk_demod_stats.py is GPL-3.0-or-later, unused
License:        LGPL-2.1-only
Group:          Productivity/Hamradio/Other
URL:            https://rowetel.com/codec2.html
Source:         https://github.com/drowe67/codec2/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source2:        baselibs.conf
Patch0:         codec2-1.2.0-install-binaries.patch
BuildRequires:  c++_compiler
BuildRequires:  cmake >= 3.13
BuildRequires:  pkgconfig

%description
Codec 2 is a speech codec designed for communications quality speech
between 700 and 3200 bit/s.

%package -n %{libname}
Summary:        Low bit rate speech codec
Group:          System/Libraries

%description -n %{libname}
Codec 2 is a speech codec designed for communications quality speech
between 700 and 3200 bit/s.

%package devel
Summary:        Development library for codec2
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
Codec 2 is a speech codec designed for communications quality speech
between 700 and 3200 bit/s.

%package examples
Summary:        Example code for Codec 2
Group:          Productivity/Hamradio/Other
BuildArch:      noarch

%description examples
Example code for Codec 2, including test voices and matlab/octave files.

%prep
%autosetup -p1
rm -rf octave/

%build
%cmake \
  -DUNITTEST=FALSE
%cmake_build

%install
%cmake_install
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -rv raw wav %{buildroot}%{_datadir}/%{name}/

%ldconfig_scriptlets -n %{libname}

%files
%license COPYING
%{_bindir}/*

%files -n %{libname}
%license COPYING
%doc README*
%{_libdir}/libcodec2.so.*

%files devel
%license COPYING
%{_includedir}/*
%dir %{_libdir}/cmake/codec2
%{_libdir}/cmake/codec2/codec2-config-relwithdebinfo.cmake
%{_libdir}/cmake/codec2/codec2-config.cmake
%{_libdir}/libcodec2.so
%{_libdir}/pkgconfig/%{name}.pc

%files examples
%license COPYING
%{_datadir}/%{name}

%changelog
* Mon Jul 31 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.2.0
  * sources reorganized upstream
- package the command binaries
  codec2-1.2.0-install-binaries.patch
* Thu Jun 15 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 1.1.1
  * Minor release to support clean freedv-gui builds
* Thu May 25 2023 Martin Pluskal <mpluskal@suse.com>
- Update baselibs.conf to match change of shared library name
* Sat May  6 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 1.1.0
  * Internal maintenance.
  * Tx peak levels normalised across modes.
  * New raw data modes to support FreeDATA.
* Sun Jul 17 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 1.0.5
  * Bump version to 1.0.5 to clearly delineate from various 1.0.4
    tags, otherwise the same as 1.0.4_rc2
- Update to version 1.0.4
  * 2020B,
  * build system and tools maintenance.
  * This RC fixes FreeDV API backwards compatibility issue in v1.0.4
* Fri Jan 21 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.0.3:
  * Internal changes only
- Drop no longer needed patches:
  * moved-freedv_callback_rx_sym-into-internal-header.patch
  * codec2-no_return_random.patch
- Disable unit tests as they were not run anyways and require octave
* Tue Oct  5 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Added a patch moved-freedv_callback_rx_sym-into-internal-header.patch
  to fix building gnuradio (patch taken from upstream)
* Sat Oct  2 2021 Martin Hauke <mardnh@gmx.de>
- Drop handcrafted generation of the pkgconfig file
- Remove "-Wno-dev"
* Mon Sep 27 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 1.0.1:
  * Release to support freedv-gui 1.6.1
* Tue Aug 17 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update baselib.conf
* Mon Aug 16 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 1.0.0:
  * No upstream changelog available
  * Added new mode 700E
- Test binaries not installed now, so package codec2 dropped,
  license and doc files moved to libcodec2 library.
- Patch codec2-no_return_random.patch rebased.
* Mon Mar  9 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.9.2:
  * No upstream changelog available
- Drop no longer needed patches:
  * codec2-licensed-stuff.patch
* Sat Aug 11 2018 tchvatal@suse.com
- Apply upstream patch to fix ambiguous license situation:
  * codec2-licensed-stuff.patch
* Tue Jul 17 2018 mpluskal@suse.com
- Update to version 0.8.1:
  * No upstream changelog provided
- Add codec2-no_return_random.patch
- Add baselibs.conf
* Mon Jul 31 2017 wk@ire.pw.edu.pl
- Update to version 0.7
* Tue May 30 2017 mpluskal@suse.com
- Update licensing information
* Sun Apr 16 2017 mardnh@gmx.de
- Update to version 0.6:
  * No upstream changelog available
* Wed Mar 15 2017 jengelh@inai.de
- Update description with new bit rates from homepage.
* Tue Mar 14 2017 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
* Tue Jan 17 2017 dl8fcl@darc.de
- Copyrigth information of spec file removed
* Sat Jan 14 2017 aloisio@gmx.com
- Version 0.5.1
  * Updated golay
- Spec cleanup
- Added codec2-rpmlintrc
* Sun Oct 11 2015 wk@ire.pw.edu.pl
- version 0.5
* Fri Sep 18 2015 wk@ire.pw.edu.pl
- version 0.4.1
* Tue Aug 18 2015 wk@ire.pw.edu.pl
- patch to install copm_prim.h needed by freedv2
* Tue Aug 18 2015 wk@ire.pw.edu.pl
- version 0.4
* Sun Feb 15 2015 wk@ire.pw.edu.pl
- version 0.3svn1917
- mods based on Fedora package
* Mon Apr 29 2013 dl8fcl@darc.de
- first try
